library(testthat)
#library(robcp)

test_check("robcp")
